@@ -207,11 +207,13 @@ static const FFCodec * const codec_list[] = {
     &ff_h264_qsv_encoder,
     &ff_h264_v4l2m2m_encoder,
     &ff_h264_vaapi_encoder,
+    &ff_h264_vulkan_encoder,
     &ff_hevc_amf_encoder,
     &ff_hevc_nvenc_encoder,
     &ff_hevc_qsv_encoder,
     &ff_hevc_v4l2m2m_encoder,
     &ff_hevc_vaapi_encoder,
+    &ff_hevc_vulkan_encoder,
     &ff_mjpeg_qsv_encoder,
     &ff_mjpeg_vaapi_encoder,
     &ff_mpeg2_qsv_encoder,
@@ -757,6 +759,7 @@ static const FFCodec * const codec_list[] = {
     &ff_vp8_qsv_decoder,
     &ff_vp9_cuvid_decoder,
     &ff_vp9_qsv_decoder,
+    &ff_vvc_qsv_decoder,
     &ff_vnull_decoder,
     &ff_anull_decoder,
     NULL };
